==> migrate_wizard-1.0.8-alpha1.tar.gz: migrate_wizard/src/Form/BaseFormFieldsTrait.php <==
<?php


namespace Drupal\migrate_wizard\Form;


use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\migrate_wizard\MWConfigBuilder;
use Drupal\migrate_wizard\MWManageDataService;
use Drupal\migrate_wizard\MWManageFormService;
use Symfony\Component\DependencyInjection\ContainerInterface;

trait BaseFormFieldsTrait {

  /**
   * {@inheritdoc}
   */
  protected $mwManageDataService;

  /**
   * {@inheritdoc}
   */
  protected $mwConfigBuilder;

  /**
   * {@inheritdoc}
   */
  protected $fieldsOriginBundle;

  /**
   * {@inheritdoc}
   */
  protected $arrayFieldsOriginBundle;

  /**
   * {@inheritdoc}
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  protected $entityFieldManager;

  /**
   * {@inheritdoc}
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  protected $entityFieldsDestiny;
  /**
   * {@inheritdoc}
   */
  protected $destinyType;
  protected $originType;
  protected $currentConfig;
  protected $originBundle;
  protected $manageFormService;
  protected $checkboxes = [
    'build_migration_config' => 'Build migration config',
  ];
  protected $langCodes = [
    'default_lang' => ['markup' => 'Default translation', 'value' => ''],
  ];

  protected $i18nMode;
  /**
   * {@inheritdoc}
   */
  public function __construct(MWManageDataService $mw_manage_data_service,
                              MWConfigBuilder $mw_config_builder,
                              ConfigFactoryInterface $config_factory,
                              EntityFieldManagerInterface $entity_field_manager,
                              EntityTypeManagerInterface $entity_type_manager,
                              MWManageFormService $manage_form_service) {
    $this->mwManageDataService = $mw_manage_data_service;
    $this->mwConfigBuilder = $mw_config_builder;
    $this->config = $config_factory->getEditable('migrate_wizard.settings');
    $this->entityFieldManager = $entity_field_manager;
    $this->entityTypeManager = $entity_type_manager;
    $this->originBundle = \Drupal::request()->attributes->get('origin_bundle');
    $this->currentConfig = $this->config->get($this->originBundle);
    $this->destinyType = isset($this->currentConfig["destiny_type"]) ? $this->currentConfig["destiny_type"] : '';
    $this->manageFormService = $manage_form_service;
    //TODO investigate how set origin type here
//    $this->fieldsOriginBundle = $this->manageFormService->getFieldsOriginBundle($this->originBundle);
//    $this->manageFormService->setFieldsOriginBundle($this->fieldsOriginBundle);
    $this->manageFormService->setCurrentConfig($this->currentConfig);
    $this->manageFormService->setConfig($this->config);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
      $container->get('migrate_wizard.migrate_wizard_config_builder_service'),
      $container->get('config.factory'),
      $container->get('entity_field.manager'),
      $container->get('entity_type.manager'),
      $container->get('migrate_wizard.migrate_wizard_manage_form_service'),
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['migrate_wizard.settings'];
  }

}

==> migrate_wizard-2.0.2-alpha1.tar.gz: migrate_wizard/src/Form/BaseFormFieldsTrait.php <==
<?php


namespace Drupal\migrate_wizard\Form;


use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\migrate_wizard\MWConfigBuilder;
use Drupal\migrate_wizard\MWManageDataService;
use Drupal\migrate_wizard\MWManageFormService;
use Symfony\Component\DependencyInjection\ContainerInterface;

trait BaseFormFieldsTrait {

  /**
   * {@inheritdoc}
   */
  protected $mwManageDataService;

  /**
   * {@inheritdoc}
   */
  protected $mwConfigBuilder;

  /**
   * {@inheritdoc}
   */
  protected $fieldsOriginBundle;

  /**
   * {@inheritdoc}
   */
  protected $arrayFieldsOriginBundle;

  /**
   * {@inheritdoc}
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  protected $entityFieldManager;

  /**
   * {@inheritdoc}
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  protected $entityFieldsDestiny;
  /**
   * {@inheritdoc}
   */
  protected $destinyType;
  protected $originType;
  protected $currentConfig;
  protected $originBundle;
  protected $manageFormService;
  protected $checkboxes = [
    'build_migration_config' => 'Build migration config',
  ];
  protected $langCodes = [
    'default_lang' => ['markup' => 'Default translation', 'value' => ''],
  ];

  protected $i18nMode;
  /**
   * {@inheritdoc}
   */
  public function __construct(MWManageDataService $mw_manage_data_service,
                              MWConfigBuilder $mw_config_builder,
                              ConfigFactoryInterface $config_factory,
                              EntityFieldManagerInterface $entity_field_manager,
                              EntityTypeManagerInterface $entity_type_manager,
                              MWManageFormService $manage_form_service) {
    $this->mwManageDataService = $mw_manage_data_service;
    $this->mwConfigBuilder = $mw_config_builder;
    $this->config = $config_factory->getEditable('migrate_wizard.settings');
    $this->entityFieldManager = $entity_field_manager;
    $this->entityTypeManager = $entity_type_manager;
    $this->originBundle = \Drupal::request()->attributes->get('origin_bundle');
//    $this->currentConfig = $this->config->get($this->originBundle);
    $this->destinyType = isset($this->currentConfig["destiny_type"]) ? $this->currentConfig["destiny_type"] : '';
    $this->manageFormService = $manage_form_service;
    //TODO investigate how set origin type here
//    $this->entityTypeManager->getStorage('origin_node')->load($this->originBundle);
//
//
//    $this->manageFormService->setCurrentConfig($this->currentConfig);
//    $this->manageFormService->setConfig($this->config);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
      $container->get('migrate_wizard.migrate_wizard_config_builder_service'),
      $container->get('config.factory'),
      $container->get('entity_field.manager'),
      $container->get('entity_type.manager'),
      $container->get('migrate_wizard.migrate_wizard_manage_form_service'),
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['migrate_wizard.settings'];
  }

}
